@@ -1,5 +1,5 @@
-import builtins
 import os
+import pathlib
 import webbrowser
 
 import click
@@ -15,14 +15,14 @@ from oort.cli.supervisor import (get_supervisor_processes_status,
                                  stop_supervisor_daemon,
                                  stop_supervisor_processes)
 from oort.server.errors import InvalidWatchOptionsOortCloudError
-from oort.shared.config import (get_config_upload_folder_sections,
-                                get_config_value,
-                                get_log_file_path,
-                                get_supervisor_conf_file_path,
-                                update_config_upload_folder_sections_key)
+from oort.shared.config import (get_oort_config_upload_folder_sections,
+                                get_oort_config_value,
+                                get_oort_log_file_path,
+                                get_oort_supervisor_conf_file_path,
+                                update_oort_config_upload_folder_sections_key)
+from oort.shared.constants import OORT_UPLOADER_FOLDER_DETECTION_TICK_SECONDS
 from oort.shared.errors import OortCloudError
 from oort.shared.utils import tail
-from oort.uploader.main import paths_observer
 
 pass_state = click.make_pass_decorator(State, ensure=True)
 
@@ -96,8 +96,10 @@ def main(ctx, version=False, **kwargs):
 
 
 @main.command()
-@click.option('--username', required=True, nargs=1, prompt=True)
-@click.option('--password', required=True, nargs=1, prompt=True, hide_input=True)
+@click.option('--username', required=True, nargs=1, prompt=True,
+              help="Username of the Arcsecond account. Primary email address is also allowed.")
+@click.option('--password', required=True, nargs=1, prompt=True, hide_input=True,
+              help="Password of the Arcsecond account. It will be sent encrypted.")
 @basic_options
 @pass_state
 def login(state, username, password):
@@ -109,12 +111,18 @@ def login(state, username, password):
     Beware that the key will be stored locally on a file:
     ~/.arcsecond.ini
     """
-    _, error = ArcsecondAPI.login(username, password, None, upload_key=True, debug=state.debug, verbose=state.verbose)
+    profile, error = ArcsecondAPI.login(username,
+                                        password,
+                                        None,
+                                        upload_key=True,
+                                        debug=state.debug,
+                                        verbose=state.verbose)
     if error is not None:
         click.echo(error)
     else:
-        click.echo(f' • Successfully logged in as @{username}.')
-        update_config_upload_folder_sections_key(ArcsecondAPI.upload_key())
+        click.echo(f' • Successfully logged in as @{ArcsecondAPI.username()}.')
+        # Update all upload_key stored in the config for all watched folders.
+        update_oort_config_upload_folder_sections_key(ArcsecondAPI.upload_key())
 
 
 @main.command(help='Display current Oort processes status.')
@@ -155,8 +163,8 @@ def restart(state):
 @basic_options
 @pass_state
 def open(state):
-    host = get_config_value('server', 'host')
-    port = get_config_value('server', 'port')
+    host = get_oort_config_value('server', 'host')
+    port = get_oort_config_value('server', 'port')
     webbrowser.open(f"http://{host}:{port}")
 
 
@@ -165,7 +173,7 @@ def open(state):
 @basic_options
 @pass_state
 def logs(state, n):
-    with builtins.open(get_log_file_path(), 'r') as f:
+    with get_oort_log_file_path().open('r') as f:
         print(''.join(tail(f, n or 10)))
 
 
@@ -173,101 +181,22 @@ def logs(state, n):
 @basic_options
 @pass_state
 def config(state):
-    with builtins.open(get_supervisor_conf_file_path(), 'r') as f:
+    with get_oort_supervisor_conf_file_path().open('r') as f:
         print(f.read())
 
 
-@main.command()
-@click.argument('folders', required=True, nargs=-1)
-@click.option('-o', '--organisation',
-              required=False,
-              nargs=1,
-              help="The Organisation subdomain, if uploading to an organisation.")
-@click.option('-t', '--telescope',
-              required=False,
-              nargs=1,
-              type=click.UUID,
-              help="The UUID of the telescope acquiring data (in the case of organisation uploads).")
-@click.option('--astronomer',
-              required=False,
-              nargs=2,
-              type=(str, str),
-              default=[None, None],
-              help="A astronomer on behalf of whom you upload. You MUST provide its username and api key.")
-@basic_options
-@pass_state
-def watch(state, folders, o=None, organisation=None, t=None, telescope=None, astronomer=(None, None)):
-    """
-    Indicate a folder (or multiple folders) that Oort should watch.
-
-    If an organisation is provided, a telescope UUID must also be provided.
-
-    If an organisation is provided, no custom astronomer can be used. Inversely,
-    if a custom astronomer is provided, no organisation can be used.
-
-    Oort will start by walking through the folder tree and uploads files
-    according to the name of the subfolders (see main help). Once done,
-    every new file created in the folder tree will trigger a sync + upload
-    process.
-    """
-    try:
-        username, upload_key, org_subdomain, org_role, telescope_details = \
-            parse_upload_watch_options(o, organisation, t, telescope, astronomer, state.debug, state.verbose)
-    except InvalidWatchOptionsOortCloudError:
-        return
-
-    click.echo(" --- Folder(s) watch summary --- ")
-    click.echo(f" • Arcsecond username: @{username} (Upload key: {upload_key[:4]}...)")
-    if org_subdomain:
-        click.echo(f" • Uploading for organisation: {org_subdomain} (role: {org_role})")
-    else:
-        click.echo(" • Uploading to a *personal* account (use option '-o <subdomain>' for an organisation).")
-
-    if telescope_details:
-        name, uuid = telescope_details.get('name'), telescope_details.get('uuid')
-        click.echo(f" • Night Logs will be linked to telescope '{name}' ({uuid}).")
-    else:
-        click.echo(" • No designated telescope.")
-
-    click.echo(" • Dates inside FITS/XISF files are assumed to be local dates.")
-
-    if len(folders) == 1:
-        click.echo(f" • Folder path: {os.path.expanduser(os.path.realpath(folders[0]))}")
-    else:
-        click.echo(" • Folder paths:")
-        for folder in folders:
-            click.echo(f"   > {os.path.expanduser(os.path.realpath(folder))}")
-
-    ok = input(' --> OK? (Press Enter) ')
-
-    if ok.strip() == '':
-        oort_folder = os.path.dirname(os.path.dirname(__file__))
-        prepared_folders = save_upload_folders(folders,
-                                               username,
-                                               upload_key,
-                                               org_subdomain,
-                                               org_role,
-                                               telescope_details,
-                                               state.debug,
-                                               state.verbose)
-
-        for (folder_path, identity) in prepared_folders:
-            # paths_observer.observe_folder will deal with the initial walk.
-            paths_observer.observe_folder(folder_path, identity)
-
-
 @main.command(help="Display the list of all watched folders and their options.")
 @basic_options
 @pass_state
 def folders(state):
-    sections = get_config_upload_folder_sections()
+    sections = get_oort_config_upload_folder_sections()
     if len(sections) == 0:
         click.echo(" • No folder watched. Use `oort watch` (or `oort watch --help` for more details).")
     else:
         for index, section in enumerate(sections):
             click.echo(f" • Folder #{index + 1}:")
             click.echo(f"   username     = @{section.get('username')}")
-            click.echo(f"   upload_key   = {section.get('upload_key')[0:4]}•••••••")
+            click.echo(f"   upload_key   = {section.get('upload_key')[0:4]}••••")
             if section.get('subdomain'):
                 click.echo(f"   organisation = {section.get('subdomain')} (role: {section.get('role')})")
             else:
@@ -277,26 +206,26 @@ def folders(state):
             else:
                 click.echo("   telescope    = (no telescope)")
             click.echo(f"   path         = {section.get('path')}")
+            click.echo(f"   zip          = {section.get('zip', 'False')}")
             click.echo()
 
 
 @main.command(help="Display the list of (organisation) telescopes.")
 @click.option('-o', '--organisation',
-              required=False,
-              nargs=1,
+              required=False, nargs=1,
               help="The Organisation subdomain, if uploading to an organisation.")
 @basic_options
 @pass_state
-def telescopes(state, o=None, organisation=None):
+def telescopes(state, organisation=None):
     test = os.environ.get('OORT_TESTS') == '1'
     kwargs = {'debug': state.debug, 'test': test, 'verbose': state.verbose}
 
-    org_subdomain = o or organisation or ''
+    org_subdomain = organisation or ''
     if org_subdomain:
         kwargs.update(organisation=org_subdomain)
         click.echo(f" • Fetching telescopes for organisation {org_subdomain}...")
     else:
-        click.echo(f" • Fetching telescopes...")
+        click.echo(" • Fetching telescopes...")
 
     telescope_list, error = ArcsecondAPI.telescopes(**kwargs).list()
     if error:
@@ -307,3 +236,88 @@ def telescopes(state, o=None, organisation=None):
         s = f" 🔭 \"{telescope_dict['name']}\" (UUID: {telescope_dict['uuid']}) "
         s += f"[ObservingSite UUID: {telescope_dict['observing_site']}]"
         click.echo(s)
+
+
+@main.command(help='Start watching a folder for files.')
+@click.argument('folders', required=True, nargs=-1)
+@click.option('-o', '--organisation',
+              required=False, nargs=1,
+              help="The Organisation subdomain, if uploading to an organisation.")
+@click.option('-t', '--telescope',
+              required=False, nargs=1, type=click.UUID,
+              help="The UUID of the telescope acquiring data (in the case of organisation uploads).")
+@click.option('-z', '--zip',
+              required=False, nargs=1, type=click.BOOL,
+              help="Zip the data files (FITS and XISF) before sending to the cloud. Default is False.")
+# @click.option('--astronomer',
+#               required=False, nargs=2, type=(str, str), default=[None, None],
+#               help="A astronomer on behalf of whom you upload. You MUST provide its username and upload key.")
+@basic_options
+@pass_state
+def watch(state, folders, organisation=None, telescope=None, zip=False):
+    """
+    Indicate a folder (or multiple folders) that Oort should watch. The files of the
+    folder and all of its subfolders will be uploaded (expect hidden files).
+
+    If an organisation is provided, a telescope UUID must also be provided.
+
+    If a custom astronomer is provided, it means files will be uploaded to that
+    particular *personal* account. It can be used by telescope hosting organisations
+    uploading files on behalf of someone.
+
+    Oort will start by walking through the folder tree and uploads files
+    according to the name of the subfolders (see main help). Once done,
+    every new file created in the folder tree will trigger a sync + upload
+    process.
+    """
+    try:
+        username, upload_key, org_subdomain, org_role, telescope_details = \
+            parse_upload_watch_options(organisation, telescope, state.debug, state.verbose)
+    except InvalidWatchOptionsOortCloudError:
+        return
+
+    click.echo(" --- Folder(s) watch summary --- ")
+    click.echo(f" • Arcsecond username: @{username} (Upload key: {upload_key[:4]}••••)")
+    if not org_subdomain:
+        click.echo(" • Uploading to your *personal* account.")
+    else:
+        click.echo(f" • Uploading to organisation account '{org_subdomain}' (as {org_role}).")
+
+    if telescope_details:
+        name, uuid = telescope_details.get('name'), telescope_details.get('uuid')
+        click.echo(f" • Night Logs will be linked to telescope '{name}' ({uuid}).")
+    else:
+        click.echo(" • No designated telescope.")
+
+    home_path = pathlib.Path.home()
+    existing_folders = [section.get('path') for section in get_oort_config_upload_folder_sections()]
+
+    click.echo(f" • Folder path{'s' if len(folders) > 1 else ''}:")
+    for folder in folders:
+        folder_path = pathlib.Path(folder).expanduser().resolve()
+        if folder_path.is_file():
+            folder_path = folder_path.parent
+        click.echo(f"   > {str(folder_path)}")
+        if folder_path == home_path:
+            click.echo("   >>> Warning: This watched folder is your HOME folder. <<<")
+        if str(folder_path) in existing_folders:
+            click.echo("   >>> Warning: This folder is already watched. Continuing will override its parameters. <<<")
+
+    ok = input('\n   ----> OK? (Press Enter) ')
+
+    if ok.strip() == '':
+        save_upload_folders(folders,
+                            username,
+                            upload_key,
+                            org_subdomain,
+                            org_role,
+                            telescope_details,
+                            zip,
+                            state.debug,
+                            state.verbose)
+
+        click.echo("\n • OK.")
+        msg = f" • Watch will start within {OORT_UPLOADER_FOLDER_DETECTION_TICK_SECONDS} seconds "
+        msg += "if the uploader process is running.\n • Getting processes status for you right now:"
+        click.echo(msg)
+        get_supervisor_processes_status(debug=state.debug)
