@@ -1,4 +1,5 @@
 import os
+import pathlib
 from typing import Optional, Union
 
 import click
@@ -10,7 +11,7 @@ from oort.server.errors import (InvalidAstronomerOortCloudError, InvalidOrgMembe
                                 InvalidOrganisationTelescopeOortCloudError,
                                 InvalidOrganisationUploadKeyOortCloudError, InvalidWatchOptionsOortCloudError,
                                 UnknownOrganisationOortCloudError)
-from oort.shared.config import get_logger
+from oort.shared.config import get_oort_logger
 from oort.shared.identity import Identity
 from oort.shared.models import Organisation
 
@@ -40,10 +41,16 @@ def check_remote_organisation(org_subdomain: str, debug: bool, verbose: bool):
 
 def check_local_astronomer_remote_organisation_membership(org_subdomain: str, debug: bool, verbose: bool) -> str:
     test = os.environ.get('OORT_TESTS') == '1'
+
+    # Reading local memberships if a org_subdomain is provided.
     memberships = ArcsecondAPI.memberships(debug=debug, test=test, verbose=verbose) if org_subdomain else None
+
+    # An org_subdomain is provided, but memberships are empty.
     if org_subdomain and memberships in [None, {}]:
         raise InvalidOrgMembershipOortCloudError(org_subdomain)
 
+    # Ok, an org_subdomain is provided and memberships are not empty. Checking for membership
+    # of that org_subdomain AND checking it is at least a member (not a visitor).
     role = memberships.get(org_subdomain, None)
     if not role or role not in ['member', 'admin', 'superadmin']:
         raise InvalidOrgMembershipOortCloudError(org_subdomain)
@@ -120,17 +127,14 @@ def check_organisation_uploadkeys(org_subdomain: str, username: str, upload_key:
         raise InvalidOrganisationUploadKeyOortCloudError(org_subdomain, username, upload_key)
 
 
-def parse_upload_watch_options(o: Optional[str] = None,
-                               organisation: Optional[str] = None,
-                               t: Optional[str] = None,
+def parse_upload_watch_options(organisation: Optional[str] = None,
                                telescope: Optional[str] = None,
-                               astronomer: Union[Optional[str], Optional[str]] = (None, None),
                                debug: Optional[bool] = False,
                                verbose: Optional[bool] = False):
-    telescope_uuid = t or telescope or ''
-    org_subdomain = o or organisation or ''
+    telescope_uuid = telescope or ''
+    org_subdomain = organisation or ''
 
-    ### Validation of the organisation ###
+    # Validation of the organisation #
 
     org = None
     org_role = ''
@@ -140,80 +144,89 @@ def parse_upload_watch_options(o: Optional[str] = None,
         # Check that the provided subdomain is an organisation of which the current logged in astronomer is a member.
         org_role = check_local_astronomer_remote_organisation_membership(org_subdomain, debug, verbose)
 
-    ### Validation of the telescope ###
+    # Validation of the telescope #
 
     # In every case, check for telescope details if a UUID is provided.
     telescope_details = None
     if telescope_uuid:
         telescope_details = check_organisation_telescope(telescope_uuid, org_subdomain, debug, verbose)
 
-    ### Validation of the uploader ###
+    # Validation of the uploader #
 
     username = ''
     upload_key = ''
+    # custom_astronomer = False
 
-    # No custom astronomer for uploading. If no org, fine. If an org, one need the telescope.
-    if astronomer == (None, None):
-        # Fetch the username of the currently logged in astronomer.
-        username, upload_key = check_local_astronomer(debug, verbose)
-        if not username or not upload_key:
-            raise InvalidWatchOptionsOortCloudError('Missing username or upload_key.')
+    # --- for when we will deal with custom astronomers
+    # No custom astronomer for uploading. If no org, fine. If an org, one needs the telescope.
+    # if astronomer == (None, None):
 
-        # If we have an organisation and no telescope UUID, we list the one available
-        # and then raise an error
-        if org is not None and telescope_details is None:
-            list_organisation_telescopes(org_subdomain, debug, verbose)
-            raise InvalidWatchOptionsOortCloudError('For an organisation, a telescope UUID must be provided.')
+    # Fetch the username of the currently logged in astronomer.
+    username, upload_key = check_local_astronomer(debug, verbose)
+    if not username or not upload_key:
+        raise InvalidWatchOptionsOortCloudError('Missing username or upload_key.')
 
+    # If we have an organisation and no telescope UUID, we list the one available
+    # and then raise an error
+    if org is not None and telescope_details is None:
+        list_organisation_telescopes(org_subdomain, debug, verbose)
+        raise InvalidWatchOptionsOortCloudError('For an organisation, a telescope UUID must be provided.')
+
+    # --- for when we will deal with custom astronomers
     # We have a custom astronomer. Check that the organisation is allowed to upload on behalf of it.
-    else:
-        username, upload_key = astronomer
-        # Make sure the remote astronomer actually exists.
-        check_remote_astronomer(username, upload_key, debug, verbose)
-
-        if org is None:
-            raise InvalidWatchOptionsOortCloudError('')
-
-        # Check that the custom astronomer has a valid upload_key for the given organisation.
-        # This is where the knot is. This check can only be made by a member of the registered organisation.
-        check_organisation_uploadkeys(org_subdomain, username, upload_key, debug, verbose)
+    # else:
+    #     custom_astronomer = True
+    #     username, upload_key = astronomer
+    #     # Make sure the remote astronomer actually exists.
+    #     check_remote_astronomer(username, upload_key, debug, verbose)
+    #
+    #     if org is None:
+    #         raise InvalidWatchOptionsOortCloudError(
+    #             'To check the custom astronomer, one needs the uploading organisation'
+    #         )
+    #
+    #     # Check that the custom astronomer has a valid upload_key for the given organisation.
+    #     # This is where the knot is. This check can only be made by a member of the registered organisation.
+    #     check_organisation_uploadkeys(org_subdomain, username, upload_key, debug, verbose)
 
     return username, upload_key, org_subdomain, org_role, telescope_details
 
 
 def save_upload_folders(folders: list,
-                        username: Optional[str],
-                        upload_key: Optional[str],
+                        username: str,
+                        upload_key: str,
                         org_subdomain: Optional[str],
                         org_role: Optional[str],
                         telescope_details: Optional[dict],
+                        zip: bool,
                         debug: bool,
                         verbose: bool) -> list:
-    logger = get_logger('cli', debug=debug)
+    logger = get_oort_logger('cli', debug=debug)
+
     prepared_folders = []
     for raw_folder in folders:
-        upload_folder = os.path.expanduser(os.path.realpath(raw_folder))
-        if not os.path.exists(upload_folder) and os.environ.get('OORT_TESTS') != '1':
-            logger.warn(f'Upload folder "{upload_folder}" does not exists. Skipping.')
+        upload_path = pathlib.Path(raw_folder).resolve()
+
+        if not upload_path.exists() and os.environ.get('OORT_TESTS') != '1':
+            logger.warn(f'Upload folder "{upload_path}" does not exists. Skipping.')
             continue
-        if os.path.isfile(upload_folder):
-            upload_folder = os.path.dirname(upload_folder)
+
+        if upload_path.is_file():
+            upload_path = upload_path.parent
 
         telescope_uuid = ''
-        longitude = None
         if telescope_details:
             telescope_uuid = telescope_details.get('uuid') or ''
-            longitude = telescope_details.get('coordinates').get('longitude') or ''
 
         identity = Identity(username=username,
                             upload_key=upload_key or '',
                             subdomain=org_subdomain or '',
                             role=org_role or '',
                             telescope=telescope_uuid,
-                            longitude=longitude,
+                            zip=zip,
                             debug=debug)
 
-        identity.save_with_folder(upload_folder_path=upload_folder)
-        prepared_folders.append((upload_folder, identity))
+        identity.save_with_folder(upload_folder_path=str(upload_path))
+        prepared_folders.append((str(upload_path), identity))
 
     return prepared_folders
