@@ -1,4 +1,7 @@
+import atexit
+import math
 import pathlib
+import time
 from datetime import datetime
 from enum import Enum
 
@@ -11,21 +14,28 @@ from peewee import (
     ForeignKeyField,
     IntegerField,
     Model,
-    SqliteDatabase,
     UUIDField
 )
-from playhouse.signals import Signal
+from playhouse.migrate import SqliteMigrator, migrate
+from playhouse.sqliteq import SqliteQueueDatabase
 
-from oort.shared.config import get_db_file_path
-from oort.shared.config import get_logger
+from oort.shared.config import get_oort_db_file_path
 from oort.shared.constants import ZIP_EXTENSIONS
 from oort.uploader.engine.errors import MultipleDBInstanceError
 
-db = SqliteDatabase(get_db_file_path(), pragmas={'journal_mode': 'wal', 'cache_size': -1024 * 64})
+# Create global instance 'db'
+db = SqliteQueueDatabase(str(get_oort_db_file_path()),
+                         use_gevent=False,
+                         autostart=True,
+                         queue_max_size=64,
+                         results_timeout=5.0,
+                         pragmas={'journal_mode': 'wal', 'cache_size': -1024 * 64})
 
-upload_post_save_signal = Signal()
 
-logger = get_logger('db')
+# Make sure write thread is stopped upon exit.
+@atexit.register
+def _stop_worker_threads():
+    db.stop()
 
 
 class BaseModel(Model):
@@ -34,15 +44,6 @@ class BaseModel(Model):
 
     _primary_field = 'uuid'
 
-    @classmethod
-    def exists(cls, **kwargs):
-        try:
-            cls.get(**kwargs)
-        except DoesNotExist:
-            return False
-        else:
-            return True
-
     @classmethod
     def get_field(cls, name):
         return cls._meta.sorted_fields[cls._meta.sorted_field_names.index(name)]
@@ -67,6 +68,8 @@ class BaseModel(Model):
 
     @classmethod
     def smart_get(cls, **kwargs):
+        # The following allows get queries with a ForeignKey inside kwargs.
+        # One needs it for when creating Dataset related to Observation...
         foreign_key_names = [key for key in kwargs if isinstance(cls.get_field(key), ForeignKeyField)]
         if len(foreign_key_names) > 0:
             value = kwargs.pop(foreign_key_names[0])
@@ -82,24 +85,30 @@ class BaseModel(Model):
         for foreign_key_name in foreign_items.keys():
             kwargs.pop(foreign_key_name)
 
-        with db.atomic('IMMEDIATE'):
+        # with db.atomic('IMMEDIATE'):
+        try:
+            instance = cls.get(**kwargs)
+        except DoesNotExist:
             instance = cls.create(**kwargs)
+        time.sleep(0.1)
 
         for foreign_key_name, foreign_value in foreign_items.items():
             foreign_model = cls.get_field(foreign_key_name).rel_model
             foreign_instance = foreign_model.get(foreign_model.get_primary_field() == foreign_value)
-            with db.atomic('IMMEDIATE'):
-                setattr(instance, foreign_key_name, foreign_instance)
-                instance.save()
+            setattr(instance, foreign_key_name, foreign_instance)
+            instance.save()
+            time.sleep(0.1)
 
         return instance
 
     def smart_update(self, **kwargs):
-        with db.atomic():
-            for k, v in kwargs.items():
-                setattr(self, k, v)
-            self.save()
-        upload_post_save_signal.send(self)
+        # with db.atomic():
+        id_field = getattr(self.__class__, self._primary_field)
+        id_field_value = getattr(self, self._primary_field)
+        # See https://docs.peewee-orm.com/en/latest/peewee/querying.html#atomic-updates
+        query = self.__class__.update(**kwargs).where(id_field == id_field_value)
+        query.execute()
+        return self.__class__.get_by_id(id_field_value)
 
 
 class Organisation(BaseModel):
@@ -168,8 +177,6 @@ class Substatus(Enum):
     IGNORED = 'ignored'
     # --- SKIPPED: MUST STARTED WITH THE SAME 'skipped' LOWERCASE WORD. See Context.py ---
     SKIPPED_NO_DATE_OBS = 'skipped (no date obs found)'
-    SKIPPED_NOT_FITS_OR_XISF = 'skipped (not fits or xisf)'
-    SKIPPED_NO_DATASET = 'skipped (no dataset)'
     SKIPPED_HIDDEN_FILE = 'skipped (hidden file)'
     SKIPPED_EMPTY_FILE = 'skipped (empty file)'
     # ---
@@ -178,8 +185,6 @@ class Substatus(Enum):
 FINISHED_SUBSTATUSES = [Substatus.DONE.value,
                         Substatus.ERROR.value,
                         Substatus.SKIPPED_NO_DATE_OBS.value,
-                        Substatus.SKIPPED_NOT_FITS_OR_XISF.value,
-                        Substatus.SKIPPED_NO_DATASET.value,
                         Substatus.ALREADY_SYNCED.value]
 
 PREPARATION_DONE_SUBSTATUSES = [Substatus.CHECKING.value,
@@ -190,6 +195,8 @@ PREPARATION_DONE_SUBSTATUSES = [Substatus.CHECKING.value,
 
 
 class Upload(BaseModel):
+    _primary_field = 'id'
+
     created = DateTimeField(default=datetime.now)
 
     file_path = CharField(unique=True, null=True)
@@ -211,6 +218,7 @@ class Upload(BaseModel):
     dataset = ForeignKeyField(Dataset, null=True, backref='uploads')
     telescope = ForeignKeyField(Telescope, null=True, backref='uploads')
 
+    target_name = CharField(default='')
     astronomer = CharField(default='')
     organisation = ForeignKeyField(Organisation, backref='uploads', null=True)
 
@@ -226,6 +234,20 @@ class Upload(BaseModel):
         else:
             return u.status == Status.OK.value and u.substatus in FINISHED_SUBSTATUSES
 
+    def get_formatted_size(self) -> str:
+        size = self.file_size or self.file_size_zipped or 0
+        if size == 0:
+            return '0 Bytes'
+        k = 1024
+        units = ['Bytes', 'kB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB']
+        i = math.floor(math.log10(1.0 * size) / math.log10(k))
+        return f"{(size / math.pow(k, i)):.2f} {units[i]}"
 
-db.connect()
+
+db.connect(reuse_if_open=True)
 db.create_tables([Organisation, Telescope, NightLog, Observation, Calibration, Dataset, Upload])
+
+_migrator = SqliteMigrator(db)
+migrate(
+    _migrator.add_column(Upload._meta.table_name, 'target_name', CharField(default='')),
+)
