@@ -6,7 +6,7 @@ import warnings
 import xml.etree.ElementTree as ET
 from datetime import datetime, timedelta
 from enum import Enum, auto
-from typing import Optional
+from typing import Optional, Tuple
 
 import dateparser
 from astropy.io import fits as pyfits
@@ -14,7 +14,7 @@ from astropy.io.fits.verify import VerifyWarning
 from astropy.io.votable.exceptions import VOTableSpecWarning
 from astropy.utils.exceptions import AstropyWarning
 
-from oort.shared.config import get_logger
+from oort.shared.config import get_oort_logger
 from oort.shared.constants import ZIP_EXTENSIONS, get_all_fits_extensions, get_all_xisf_extensions
 from oort.shared.identity import Identity
 from oort.shared.models import (
@@ -63,18 +63,23 @@ class UploadPack(object):
 
     def __init__(self, root_path: str, file_path: str, identity: Identity):
         self._identity = identity
-        self._root_path = root_path
+        self._root_path = pathlib.Path(root_path)
         self._raw_file_path = pathlib.Path(file_path)
 
-        self._logger = get_logger('uloader', debug=identity.debug)
-        self._parse()
+        self._logger = get_oort_logger('uploader', debug=identity.debug)
+        self._parse_type_and_dataset_name()
 
         # Will work whatever the raw file path extension (zipped or not), and
         # whatever the current state of the two files (exists or not).
-        self._upload, created = Upload.get_or_create(file_path=self.clear_file_path)
-        self._upload.smart_update(astronomer=self._identity.username, file_path_zipped=self.zipped_file_path)
+        try:
+            self._upload = Upload.get(Upload.file_path == self.clear_file_path)
+        except Upload.DoesNotExist:
+            self._upload = Upload.create(file_path=self.clear_file_path)
 
-        self._find_date_and_sizes()
+        self.update_upload(astronomer=self._identity.username,
+                           file_path_zipped=self.zipped_file_path)
+
+        self._find_date_size_and_target_name()
 
     def do_upload(self):
         if self.should_zip:
@@ -82,40 +87,37 @@ class UploadPack(object):
             zip.start()
             return
 
-        if self.is_data_file and self._upload.file_size_zipped == 0 and self._upload.substatus == Substatus.READY.value:
-            self._logger.info(f'{self.log_prefix} {self.zipped_file_path} is zipped but size is zero?')
-            return
-
         if self.is_hidden_file:
-            self._logger.info(f'{self.log_prefix} {self.final_file_path} is an hidden file. Upload skipped.')
+            self._logger.info(f'{self.log_prefix} {self.final_file_name} is an hidden file. Upload skipped.')
             self._archive(Substatus.SKIPPED_HIDDEN_FILE.value)
             return
 
         if self.is_empty_file:
-            self._logger.info(f'{self.log_prefix} {self.final_file_path} is an empty file. Upload skipped.')
+            self._logger.info(f'{self.log_prefix} {self.final_file_name} is an empty file. Upload skipped.')
             self._archive(Substatus.SKIPPED_EMPTY_FILE.value)
             return
 
+        # Still not 100% satisfactory...
+
+        item = f"{self.final_file_name} ({self._upload.substatus})"
+        preparation_succeeded = self._upload.dataset is not None
+
         if self.should_prepare:
             upload_preparator = preparator.UploadPreparator(self, debug=self._identity.debug)
-            upload_preparator.prepare()
+            preparation_succeeded, _ = upload_preparator.prepare()
         else:
-            self._logger.info(
-                f'{self.log_prefix} Preparation already done for {self.final_file_path} ({self._upload.substatus}).'
-            )
+            self._logger.info(f'{self.log_prefix} Preparation already done for {item}.')
 
-        if self.is_already_finished:
-            self._logger.info(f'{self.log_prefix} Upload already finished for {self.final_file_path}.')
-        elif self._upload.dataset is not None:
-            file_uploader = uploader.FileUploader(self)
-            file_uploader.upload()
-        else:
-            self._logger.info(f'{self.log_prefix} Missing dataset, upload skipped for {self.final_file_path}.')
-            self._archive(Substatus.SKIPPED_NO_DATASET.value)
+        if preparation_succeeded:
+            if self.is_already_finished:
+                self._logger.info(f'{self.log_prefix} Upload already finished for {item}.')
+            else:
+                file_uploader = uploader.FileUploader(self)
+                file_uploader.upload()
 
     @property
     def log_prefix(self) -> str:
-        return '[UploadPack: ' + '/'.join(self._raw_file_path.parts[-2:]) + ']'
+        return f'[UploadPack: {self.final_file_path}]'
 
     @property
     def identity(self) -> Identity:
@@ -127,10 +129,12 @@ class UploadPack(object):
 
     @property
     def should_zip(self) -> bool:
-        return self.is_data_file and \
+        return self.identity.zip and \
+               self.is_data_file and \
                self.clear_file_exists and \
                not self.zipped_file_exists and \
-               self._upload.substatus != Substatus.ZIPPING.value
+               self._upload.substatus != Substatus.ZIPPING.value and \
+               os.access(str(self._root_path), os.W_OK)
 
     @property
     def final_file_path(self):
@@ -152,7 +156,8 @@ class UploadPack(object):
 
     @property
     def clear_file_path(self) -> str:
-        return str(self._raw_file_path.with_suffix('')) if self._raw_file_path.suffix in ZIP_EXTENSIONS \
+        return str(self._raw_file_path.with_suffix('')) \
+            if self._raw_file_path.suffix in ZIP_EXTENSIONS and len(self._raw_file_path.suffixes) > 1 \
             else str(self._raw_file_path)
 
     @property
@@ -183,10 +188,6 @@ class UploadPack(object):
         x = 0 if self._upload.file_date.hour >= 12 else 1
         return (self._upload.file_date - timedelta(days=x)).date().isoformat()
 
-    @property
-    def resource_type(self) -> str:
-        return self._type.name.lower()
-
     @property
     def resource_db_class(self):
         return Observation if self._type == ResourceType.OBSERVATION else Calibration
@@ -195,71 +196,73 @@ class UploadPack(object):
     def remote_resources_name(self) -> str:
         return self._type.name.lower() + 's'
 
+    @property
+    def resource_type(self) -> str:
+        return self._type.name.lower()
+
     @property
     def dataset_name(self) -> str:
         return self._dataset_name.strip()
 
+    @property
+    def target_name(self) -> str:
+        return self._upload.target_name.strip()
+
     @property
     def should_prepare(self) -> bool:
-        return self._upload.substatus not in PREPARATION_DONE_SUBSTATUSES
+        return self._upload.substatus not in PREPARATION_DONE_SUBSTATUSES or self._upload.dataset is None
 
     @property
     def is_already_finished(self) -> bool:
-        return self._upload.substatus in FINISHED_SUBSTATUSES
+        return self._upload.status == Status.OK.value and self._upload.substatus in FINISHED_SUBSTATUSES
 
-    def _parse(self):
-        # Remove all parts belonging to root path
-        _segments = [s for s in str(self._raw_file_path)[len(self._root_path):].split(os.sep) if s != '']
-        # Removing file name part
-        _segments.pop()
+    def _parse_type_and_dataset_name(self):
+        # No starting root, and no ending filename. Just the final folder.
+        _clean_path = self._raw_file_path.relative_to(self._root_path).parent
+        _is_calib = any([c for c in CALIB_PREFIXES if c in str(_clean_path).lower()])
 
-        self._type = ResourceType.OBSERVATION
-        self._dataset_name = None
+        self._type = ResourceType.CALIBRATION if _is_calib else ResourceType.OBSERVATION
+        self._dataset_name = str(_clean_path)
 
-        for i in range(1, min(len(_segments), 2) + 1):
-            if any([c for c in CALIB_PREFIXES if c in _segments[-i].lower()]):
-                self._type = ResourceType.CALIBRATION
-                if i == 1:
-                    self._dataset_name = _segments[-i]
-                else:  # i = 2
-                    self._dataset_name = f'{_segments[-i]}/{_segments[-1]}'
-                break
+        if len(self._dataset_name.strip()) == 0 or self._dataset_name.strip() == '.':
+            self._dataset_name = f'(folder {self._root_path.name})'
 
-        if self._type == ResourceType.OBSERVATION:
-            self._dataset_name = '/'.join(_segments)
-
-        if len(self._dataset_name.strip()) == 0:
-            self._dataset_name = f'(folder {os.path.basename(self._root_path)})'
-
-        # What happens when rules change: dataset will change -> new upload...
-
-    def _find_date_and_sizes(self):
-        _file_date = self._find_date()
+    def _find_date_size_and_target_name(self) -> None:
+        _file_date, _target_name = self._find_date_and_target_name()
         _file_size, _zipped_file_size = self._find_sizes()
-        self._upload.smart_update(file_date=_file_date, file_size=_file_size, file_size_zipped=_zipped_file_size)
+        self.update_upload(file_date=_file_date,
+                           file_size=_file_size,
+                           file_size_zipped=_zipped_file_size,
+                           target_name=_target_name or '')
 
-    def _find_sizes(self):
+    def _find_sizes(self) -> Tuple[float, float]:
         _file_size = 0
+        _zipped_file_size = 0
         if self.clear_file_exists:
             _file_size = pathlib.Path(self.clear_file_path).stat().st_size
-        _zipped_file_size = 0
         if self.zipped_file_exists:
             _zipped_file_size = pathlib.Path(self.zipped_file_path).stat().st_size
         return _file_size, _zipped_file_size
 
-    def _find_date(self):
+    def _find_date_and_target_name(self) -> Tuple[Optional[datetime], str]:
         _file_date = self._upload.file_date or None
-        if _file_date is not None:
-            return _file_date
+        _target_name = self._upload.target_name or ""
+        if _file_date is not None and _target_name != "":
+            return _file_date, _target_name
+
         file_full_extension = ''.join(self._raw_file_path.suffixes).lower()
         file_full_path = str(self._raw_file_path)
         if file_full_extension in get_all_xisf_extensions():
-            return self._find_xisf_filedate(file_full_path)
+            return self._find_xisf_file_date_and_target_name(file_full_path)
         elif file_full_extension in get_all_fits_extensions():
-            return self._find_fits_filedate(file_full_path)
+            return self._find_fits_file_date_and_target_name(file_full_path)
+        else:
+            return _file_date, _target_name
 
-    def _find_fits_filedate(self, path):
+    def _find_fits_file_date_and_target_name(self, path: str) -> Tuple[Optional[datetime], str]:
         file_date = None
+        target_name = ""
+
         hdulist = None
         try:
             with pyfits.open(path, mode='readonly', memmap=True, ignore_missing_end=True) as hdulist:
@@ -269,22 +272,24 @@ class UploadPack(object):
                     # idea as it required to force the reading of all HDUs (lazy loaded by default).
                     if index >= 10:
                         break
-                    date_header = hdu.header.get('DATE') or hdu.header.get('DATE-OBS') or hdu.header.get('DATE_OBS')
-                    if date_header:
+                    date_header = hdu.header.get('DATE-OBS') or hdu.header.get('DATE_OBS') or hdu.header.get('DATE')
+                    target_name = hdu.header.get('OBJECT', "")  # Make sure to not return None!
+                    if date_header is not None:
                         file_date = dateparser.parse(date_header)
-                        if file_date:
-                            hdulist.close()
-                            break
+                    if file_date and target_name != "":
+                        hdulist.close()
+                        break
         except Exception as error:
             if hdulist:
                 hdulist.close()
             self._logger.debug(f'{self.log_prefix} {str(error)}')
-        return file_date
 
-    def _find_xisf_filedate(self, path):
+        return file_date, target_name
+
+    def _find_xisf_file_date_and_target_name(self, path: str) -> Tuple[Optional[datetime], str]:
         header = b''
         open_method = open
-        file_last_extension = self._raw_file_path.suffix
+        file_last_extension = self._raw_file_path.suffix.lower()
         if file_last_extension in ['.gzip', '.gz']:
             open_method = gzip.open
         elif file_last_extension in ['.bzip2', '.bz2']:
@@ -305,10 +310,12 @@ class UploadPack(object):
                     header += bytes[:index] + b'</xisf>'
                 elif len(header) > 0:
                     header += bytes
-        if len(header) > 0:
-            return self._get_xisf_filedate(header)
 
-    def _get_xisf_filedate(self, header):
+        return self._get_xisf_file_date(header), self._get_xisf_target_name(header)
+
+    def _get_xisf_file_date(self, header: bytes) -> Optional[datetime]:
+        if len(header) == 0:
+            return None
         file_date = None
         prefix = './/{http://www.pixinsight.com/xisf}FITSKeyword'
         try:
@@ -326,5 +333,22 @@ class UploadPack(object):
         else:
             return file_date
 
-    def _archive(self, substatus):
-        self._upload.smart_update(status=Status.OK.value, substatus=substatus, ended=datetime.now())
+    def _get_xisf_target_name(self, header: bytes) -> str:
+        if len(header) == 0:
+            return ""
+        target_name = ""
+        prefix = './/{http://www.pixinsight.com/xisf}FITSKeyword'
+        try:
+            tree = ET.fromstring(header.decode('utf-8'))
+            tag = tree.find(prefix + '[@name="OBJECT"]')
+            if tag is not None:
+                target_name = tag.get('value').strip()
+        except Exception as error:
+            self._logger.debug(f'{self.log_prefix} {str(error)}')
+        return target_name
+
+    def _archive(self, substatus) -> None:
+        self.update_upload(status=Status.OK.value, substatus=substatus, ended=datetime.now())
+
+    def update_upload(self, **kwargs) -> None:
+        self._upload = self._upload.smart_update(**kwargs)
