@@ -3,13 +3,13 @@ import sys
 import time
 
 from oort.cli.folders import check_remote_organisation
-from oort.shared.config import get_logger
+from oort.shared.config import get_oort_logger
 from oort.shared.identity import Identity
 from oort.uploader.engine import packer
 
 
 def perform_walk(root_path: str, identity: Identity, debug: bool):
-    logger = get_logger('uloader', debug=debug)
+    logger = get_oort_logger('uploader', debug=debug)
     logger.info(f'Running walk for {root_path}')
 
     if identity.subdomain:
@@ -29,7 +29,7 @@ def perform_walk(root_path: str, identity: Identity, debug: bool):
 
 if __name__ == '__main__':
     root_path = sys.argv[1]
-    username, upload_key, subdomain, role, telescope, longitude, debug_str = sys.argv[2].split(",")
+    username, upload_key, subdomain, role, telescope, debug_str = sys.argv[2].split(",")
     debug = (debug_str == 'True')
-    identity = Identity(username, upload_key, subdomain, role, telescope, longitude, debug)
+    identity = Identity(username, upload_key, subdomain, role, telescope, debug)
     perform_walk(root_path, identity, debug)
