@@ -7,7 +7,7 @@ import time
 from stat import S_IREAD, S_IRGRP, S_IROTH, S_IWUSR
 from threading import Event, Thread
 
-from oort.shared.config import get_logger
+from oort.shared.config import get_oort_logger
 from oort.shared.models import Substatus, Upload
 
 zipper_stop_event = Event()
@@ -19,16 +19,16 @@ class AsyncZipper(Thread):
         self._debug = debug
         self._file_path = file_path
         self._zipped_file_path = file_path + '.gz'
-        self._upload, created = Upload.get_or_create(file_path=file_path)
+        self._upload = Upload.get(Upload.file_path == file_path)
         self._initial_substatus = self._upload.substatus
-        self._logger = get_logger('uloader', debug=debug)
+        self._logger = get_oort_logger('uploader', debug=debug)
 
     @property
     def log_prefix(self) -> str:
-        return '[AsyncZipper: ' + '/'.join(self._file_path.split(os.sep)[-2:]) + ']'
+        return f'[AsyncZipper: {self._file_path}]'
 
     def run(self):
-        self._upload.smart_update(substatus=Substatus.ZIPPING.value)
+        self._upload = self._upload.smart_update(substatus=Substatus.ZIPPING.value)
         self._logger.info(f'{self.log_prefix} Starting to gzip file: {self._file_path}...')
         # Make file read-only to avoid deletion until end
         os.chmod(self._file_path, S_IREAD | S_IRGRP | S_IROTH)
@@ -43,7 +43,7 @@ class AsyncZipper(Thread):
                             time.sleep(10)
 
         except Exception as e:
-            self._upload.smart_update(substatus=self._initial_substatus)
+            self._upload = self._upload.smart_update(substatus=self._initial_substatus)
             pathlib.Path(self._zipped_file_path).unlink(missing_ok=True)
             self._logger.error(f'{self.log_prefix} [{str(e)}] Cancelling gzip of file: {self._file_path}.')
 
@@ -55,7 +55,7 @@ class AsyncZipper(Thread):
             # Deleting original file
             pathlib.Path(self._file_path).unlink()
             # Back to upload pending status.
-            self._upload.smart_update(substatus=Substatus.PENDING.value)
+            self._upload = self._upload.smart_update(substatus=Substatus.PENDING.value)
             self._logger.info(f'{self.log_prefix} Done with gzip of file: {self._file_path}...')
             time.sleep(0.1)
 
