@@ -12,29 +12,33 @@ from oort.uploader.engine.packer import UploadPack
 from tests.utils import use_test_database
 
 spec = importlib.util.find_spec('oort')
-fixture_path = pathlib.Path(spec.origin).parent.parent / 'tests' / 'fixtures'
 
-root_path = '/Users/onekiloparsec/data/'
+root_path = pathlib.Path(spec.origin).parent.parent
+fixture_path = root_path / 'tests' / 'fixtures'
+
 telescope_uuid = '44f5bee9-a557-4264-86d6-c877d5013788'
-identity = Identity('cedric', str(uuid.uuid4()), 'saao', 'admin', telescope_uuid)
+identity = Identity('cedric', str(uuid.uuid4()), 'saao', 'admin', telescope_uuid, True)
 
 
 @use_test_database
 def test_packer_calib_bias():
-    path = f'/Users/onekiloparsec/data/Biases{get_random_string(5)}/dummy_001.fits'
+    path = str(root_path / f'Biases{get_random_string(5)}' / 'dummy_001.fits')
     with patch('pathlib.Path.stat') as stat, \
-            patch.object(UploadPack, '_find_fits_filedate', return_value=datetime.now()), \
-            patch.object(UploadPack, '_find_xisf_filedate', return_value=datetime.now()):
+            patch.object(UploadPack, '_find_fits_file_date_and_target_name', return_value=(datetime.now(), "target")), \
+            patch.object(UploadPack, '_find_xisf_file_date_and_target_name', return_value=(datetime.now(), "target")):
         stat.return_value.st_size = random.randint(1, 1000)
 
-        pack = UploadPack(root_path, path, identity)
+        pack = UploadPack(str(root_path), path, identity)
         assert pack is not None
+        assert pack.upload is not None
         # Check detection of FITS or XISF is OK
         assert pack.is_data_file is True
         assert pack.upload.file_path == path
         assert pack.upload.file_path_zipped == path + '.gz'
         assert pack.upload.file_size > 0
         assert pack.upload.file_size_zipped > 0
+        assert pack.upload.astronomer == 'cedric'
+        assert pack.upload.target_name == 'target'
 
         # Check night log date format is OK
         assert re.match(r'[0-9]{4}-[0-9]{2}-[0-9]{2}', pack.night_log_date_string) is not None
@@ -47,13 +51,13 @@ def test_packer_calib_bias():
 
 @use_test_database
 def test_packer_calib_dark():
-    path = f'/Users/onekiloparsec/data/dArkss{get_random_string(5)}/dummy_001.fits'
+    path = str(root_path / f'dArkss{get_random_string(5)}' / 'dummy_001.fits')
     with patch('pathlib.Path.stat') as stat, \
-            patch.object(UploadPack, '_find_fits_filedate', return_value=datetime.now()), \
-            patch.object(UploadPack, '_find_xisf_filedate', return_value=datetime.now()):
+            patch.object(UploadPack, '_find_fits_file_date_and_target_name', return_value=(datetime.now(), "target")), \
+            patch.object(UploadPack, '_find_xisf_file_date_and_target_name', return_value=(datetime.now(), "target")):
         stat.return_value.st_size = random.randint(1, 1000)
 
-        pack = UploadPack(root_path, path, identity)
+        pack = UploadPack(str(root_path), path, identity)
         assert pack is not None
         # Check detection of FITS or XISF is OK
         assert pack.is_data_file is True
@@ -61,6 +65,7 @@ def test_packer_calib_dark():
         assert pack.upload.file_path_zipped == path + '.gz'
         assert pack.upload.file_size > 0
         assert pack.upload.file_size_zipped > 0
+        assert pack.upload.target_name == 'target'
 
         # Check night log date format is OK
         assert re.match(r'[0-9]{4}-[0-9]{2}-[0-9]{2}', pack.night_log_date_string) is not None
@@ -73,13 +78,13 @@ def test_packer_calib_dark():
 
 @use_test_database
 def test_packer_calibs_flat_no_filter():
-    path = f'/Users/onekiloparsec/data/FLATS{get_random_string(5)}/dummy_001.fits'
+    path = str(root_path / f'FLATS{get_random_string(5)}' / 'dummy_001.fits')
     with patch('pathlib.Path.stat') as stat, \
-            patch.object(UploadPack, '_find_fits_filedate', return_value=datetime.now()), \
-            patch.object(UploadPack, '_find_xisf_filedate', return_value=datetime.now()):
+            patch.object(UploadPack, '_find_fits_file_date_and_target_name', return_value=(datetime.now(), "target")), \
+            patch.object(UploadPack, '_find_xisf_file_date_and_target_name', return_value=(datetime.now(), "target")):
         stat.return_value.st_size = random.randint(1, 1000)
 
-        pack = UploadPack(root_path, path, identity)
+        pack = UploadPack(str(root_path), path, identity)
         assert pack is not None
         # Check detection of FITS or XISF is OK
         assert pack.is_data_file is True
@@ -87,6 +92,7 @@ def test_packer_calibs_flat_no_filter():
         assert pack.upload.file_path_zipped == path + '.gz'
         assert pack.upload.file_size > 0
         assert pack.upload.file_size_zipped > 0
+        assert pack.upload.target_name == 'target'
 
         # Check night log date format is OK
         assert re.match(r'[0-9]{4}-[0-9]{2}-[0-9]{2}', pack.night_log_date_string) is not None
@@ -99,13 +105,13 @@ def test_packer_calibs_flat_no_filter():
 
 @use_test_database
 def test_packer_calibs_flat_with_filter():
-    path = f'/Users/onekiloparsec/data/FLATS{get_random_string(5)}/U/dummy_001.fits'
+    path = str(root_path / f'FLATS{get_random_string(5)}' / 'U' / 'dummy_001.fits')
     with patch('pathlib.Path.stat') as stat, \
-            patch.object(UploadPack, '_find_fits_filedate', return_value=datetime.now()), \
-            patch.object(UploadPack, '_find_xisf_filedate', return_value=datetime.now()):
+            patch.object(UploadPack, '_find_fits_file_date_and_target_name', return_value=(datetime.now(), "target")), \
+            patch.object(UploadPack, '_find_xisf_file_date_and_target_name', return_value=(datetime.now(), "target")):
         stat.return_value.st_size = random.randint(1, 1000)
 
-        pack = UploadPack(root_path, path, identity)
+        pack = UploadPack(str(root_path), path, identity)
         assert pack is not None
         # Check detection of FITS or XISF is OK
         assert pack.is_data_file is True
@@ -113,6 +119,7 @@ def test_packer_calibs_flat_with_filter():
         assert pack.upload.file_path_zipped == path + '.gz'
         assert pack.upload.file_size > 0
         assert pack.upload.file_size_zipped > 0
+        assert pack.upload.target_name == 'target'
 
         # Check night log date format is OK
         assert re.match(r'[0-9]{4}-[0-9]{2}-[0-9]{2}', pack.night_log_date_string) is not None
@@ -125,13 +132,13 @@ def test_packer_calibs_flat_with_filter():
 
 @use_test_database
 def test_packer_observation_no_filter():
-    path = '/Users/onekiloparsec/data/HD5980/dummy_010.fits'
+    path = str(root_path / 'HD5980' / 'dummy_010.fits')
     with patch('pathlib.Path.stat') as stat, \
-            patch.object(UploadPack, '_find_fits_filedate', return_value=datetime.now()), \
-            patch.object(UploadPack, '_find_xisf_filedate', return_value=datetime.now()):
+            patch.object(UploadPack, '_find_fits_file_date_and_target_name', return_value=(datetime.now(), "target")), \
+            patch.object(UploadPack, '_find_xisf_file_date_and_target_name', return_value=(datetime.now(), "target")):
         stat.return_value.st_size = random.randint(1, 1000)
 
-        pack = UploadPack(root_path, path, identity)
+        pack = UploadPack(str(root_path), path, identity)
         assert pack is not None
         # Check detection of FITS or XISF is OK
         assert pack.is_data_file is True
@@ -139,6 +146,7 @@ def test_packer_observation_no_filter():
         assert pack.upload.file_path_zipped == path + '.gz'
         assert pack.upload.file_size > 0
         assert pack.upload.file_size_zipped > 0
+        assert pack.upload.target_name == 'target'
 
         # Check night log date format is OK
         assert re.match(r'[0-9]{4}-[0-9]{2}-[0-9]{2}', pack.night_log_date_string) is not None
@@ -151,13 +159,13 @@ def test_packer_observation_no_filter():
 
 @use_test_database
 def test_packer_observation_with_filter():
-    path = '/Users/onekiloparsec/data/HD5980/Halpha/dummy_010.fits'
+    path = str(root_path / 'HD5980' / 'Halpha' / 'dummy_010.fits')
     with patch('pathlib.Path.stat') as stat, \
-            patch.object(UploadPack, '_find_fits_filedate', return_value=datetime.now()), \
-            patch.object(UploadPack, '_find_xisf_filedate', return_value=datetime.now()):
+            patch.object(UploadPack, '_find_fits_file_date_and_target_name', return_value=(datetime.now(), "target")), \
+            patch.object(UploadPack, '_find_xisf_file_date_and_target_name', return_value=(datetime.now(), "target")):
         stat.return_value.st_size = random.randint(1, 1000)
 
-        pack = UploadPack(root_path, path, identity)
+        pack = UploadPack(str(root_path), path, identity)
         assert pack is not None
         # Check detection of FITS or XISF is OK
         assert pack.is_data_file is True
@@ -165,6 +173,7 @@ def test_packer_observation_with_filter():
         assert pack.upload.file_path_zipped == path + '.gz'
         assert pack.upload.file_size > 0
         assert pack.upload.file_size_zipped > 0
+        assert pack.upload.target_name == 'target'
 
         # Check night log date format is OK
         assert re.match(r'[0-9]{4}-[0-9]{2}-[0-9]{2}', pack.night_log_date_string) is not None
@@ -177,13 +186,13 @@ def test_packer_observation_with_filter():
 
 @use_test_database
 def test_packer_observation_with_double_filter():
-    path = '/Users/onekiloparsec/data/Tests/HD5980/Halpha/dummy_010.fits'
+    path = str(root_path / 'Tests' / 'HD5980' / 'Halpha' / 'dummy_010.fits')
     with patch('pathlib.Path.stat') as stat, \
-            patch.object(UploadPack, '_find_fits_filedate', return_value=datetime.now()), \
-            patch.object(UploadPack, '_find_xisf_filedate', return_value=datetime.now()):
+            patch.object(UploadPack, '_find_fits_file_date_and_target_name', return_value=(datetime.now(), "target")), \
+            patch.object(UploadPack, '_find_xisf_file_date_and_target_name', return_value=(datetime.now(), "target")):
         stat.return_value.st_size = random.randint(1, 1000)
 
-        pack = UploadPack(root_path, path, identity)
+        pack = UploadPack(str(root_path), path, identity)
         assert pack is not None
         # Check detection of FITS or XISF is OK
         assert pack.is_data_file is True
@@ -204,13 +213,13 @@ def test_packer_observation_with_double_filter():
 
 @use_test_database
 def test_packer_calibration_no_date_obs():
-    path = '/Users/onekiloparsec/data/Biases/dummy_010.fits'
+    path = str(root_path / 'Biases' / 'dummy_010.fits')
     with patch('pathlib.Path.stat') as stat, \
-            patch.object(UploadPack, '_find_fits_filedate', return_value=None), \
-            patch.object(UploadPack, '_find_xisf_filedate', return_value=None):
+            patch.object(UploadPack, '_find_fits_file_date_and_target_name', return_value=(None, "")), \
+            patch.object(UploadPack, '_find_xisf_file_date_and_target_name', return_value=(None, "")):
         stat.return_value.st_size = random.randint(1, 1000)
 
-        pack = UploadPack(root_path, path, identity)
+        pack = UploadPack(str(root_path), path, identity)
         assert pack is not None
         # Check detection of FITS or XISF is OK
         assert pack.is_data_file is True
@@ -231,13 +240,13 @@ def test_packer_calibration_no_date_obs():
 
 @use_test_database
 def test_packer_calibration_no_fits_no_xisf():
-    path = '/Users/onekiloparsec/data/Biases/dummy_010.csv'
+    path = str(root_path / 'Biases' / 'dummy_010.csv')
     with patch('pathlib.Path.stat') as stat, \
-            patch.object(UploadPack, '_find_fits_filedate', return_value=None), \
-            patch.object(UploadPack, '_find_xisf_filedate', return_value=None):
+            patch.object(UploadPack, '_find_fits_file_date_and_target_name', return_value=(None, "")), \
+            patch.object(UploadPack, '_find_xisf_file_date_and_target_name', return_value=(None, "")):
         stat.return_value.st_size = random.randint(1, 1000)
 
-        pack = UploadPack(root_path, path, identity)
+        pack = UploadPack(str(root_path), path, identity)
         assert pack is not None
         # Check detection of FITS or XISF is OK
         assert pack.is_data_file is False
@@ -258,32 +267,43 @@ def test_packer_calibration_no_fits_no_xisf():
 
 @use_test_database
 def test_packer_no_telescope_date_after_noon():
-    path = '/Users/onekiloparsec/data/Biases/dummy_010.fits'
+    path = str(root_path / 'Biases' / 'dummy_010.fits')
     obs_date = datetime(2020, 3, 21, hour=20, minute=56, second=35)
     with patch('os.path.getsize', return_value=10), \
-            patch.object(UploadPack, '_find_fits_filedate', return_value=obs_date), \
-            patch.object(UploadPack, '_find_xisf_filedate', return_value=None):
-        pack = UploadPack(root_path, path, identity)
+            patch.object(UploadPack, '_find_fits_file_date_and_target_name', return_value=(obs_date, "target")), \
+            patch.object(UploadPack, '_find_xisf_file_date_and_target_name', return_value=(None, "")):
+        pack = UploadPack(str(root_path), path, identity)
         assert pack.night_log_date_string == '2020-03-21'
 
 
 @use_test_database
 def test_packer_no_telescope_date_before_noon():
-    path = '/Users/onekiloparsec/data/Biases/dummy_010.fits'
+    path = str(root_path / 'Biases' / 'dummy_010.fits')
     obs_date = datetime(2020, 3, 21, hour=7, minute=56, second=35)
     with patch('os.path.getsize', return_value=10), \
-            patch.object(UploadPack, '_find_fits_filedate', return_value=obs_date), \
-            patch.object(UploadPack, '_find_xisf_filedate', return_value=None):
-        pack = UploadPack(root_path, path, identity)
+            patch.object(UploadPack, '_find_fits_file_date_and_target_name', return_value=(obs_date, "target")), \
+            patch.object(UploadPack, '_find_xisf_file_date_and_target_name', return_value=(None, "")):
+        pack = UploadPack(str(root_path), path, identity)
         assert pack.night_log_date_string == '2020-03-20'
 
 
-############## REAL FIXTURE FILES ######################################################################################
+# ############# REAL FIXTURE FILES ################################################################################### #
 
 @use_test_database
 def test_packer_non_data_non_zipped():
     path = str(fixture_path / 'non_data_non_zipped.txt')
-    pack = UploadPack(root_path, path, identity)
+    pack = UploadPack(str(root_path), path, identity)
+    assert pack.is_data_file is False
+    assert pack.is_hidden_file is False
+    assert pack.clear_file_exists is True
+    assert pack.zipped_file_exists is False
+    assert pack.should_zip is False
+
+
+@use_test_database
+def test_packer_non_data_non_zipped_added_gz():
+    path = str(fixture_path / 'non_data_non_zipped.txt.gz')
+    pack = UploadPack(str(root_path), path, identity)
     assert pack.is_data_file is False
     assert pack.is_hidden_file is False
     assert pack.clear_file_exists is True
@@ -294,7 +314,7 @@ def test_packer_non_data_non_zipped():
 @use_test_database
 def test_packer_non_data_zipped():
     path = str(fixture_path / 'non_data_zipped.txt.gz')
-    pack = UploadPack(root_path, path, identity)
+    pack = UploadPack(str(root_path), path, identity)
     assert pack.is_data_file is False
     assert pack.is_hidden_file is False
     assert pack.clear_file_exists is False
@@ -305,7 +325,18 @@ def test_packer_non_data_zipped():
 @use_test_database
 def test_packer_data_clear_with_zipped():
     path = str(fixture_path / 'data_zipped_with_clear.fits')
-    pack = UploadPack(root_path, path, identity)
+    pack = UploadPack(str(root_path), path, identity)
+    assert pack.is_data_file is True
+    assert pack.is_hidden_file is False
+    assert pack.clear_file_exists is True
+    assert pack.zipped_file_exists is True
+    assert pack.should_zip is False
+
+
+@use_test_database
+def test_packer_data_clear_with_zipped_added_gz():
+    path = str(fixture_path / 'data_zipped_with_clear.fits.gz')
+    pack = UploadPack(str(root_path), path, identity)
     assert pack.is_data_file is True
     assert pack.is_hidden_file is False
     assert pack.clear_file_exists is True
@@ -316,7 +347,7 @@ def test_packer_data_clear_with_zipped():
 @use_test_database
 def test_packer_data_zip_with_clear():
     path = str(fixture_path / 'data_zipped_with_clear.fits.zip')
-    pack = UploadPack(root_path, path, identity)
+    pack = UploadPack(str(root_path), path, identity)
     assert pack.is_data_file is True
     assert pack.is_hidden_file is False
     assert pack.clear_file_exists is True
@@ -327,7 +358,7 @@ def test_packer_data_zip_with_clear():
 @use_test_database
 def test_packer_data_gzip_with_clear():
     path = str(fixture_path / 'data_zipped_with_clear.fits.gz')
-    pack = UploadPack(root_path, path, identity)
+    pack = UploadPack(str(root_path), path, identity)
     assert pack.is_data_file is True
     assert pack.is_hidden_file is False
     assert pack.clear_file_exists is True
@@ -338,7 +369,7 @@ def test_packer_data_gzip_with_clear():
 @use_test_database
 def test_packer_data_bz2_with_clear():
     path = str(fixture_path / 'data_zipped_with_clear.fits.bz2')
-    pack = UploadPack(root_path, path, identity)
+    pack = UploadPack(str(root_path), path, identity)
     assert pack.is_data_file is True
     assert pack.is_hidden_file is False
     assert pack.clear_file_exists is True
@@ -349,7 +380,7 @@ def test_packer_data_bz2_with_clear():
 @use_test_database
 def test_packer_data_clear_no_clear():
     path = str(fixture_path / 'data_zipped_no_clear.fits')
-    pack = UploadPack(root_path, path, identity)
+    pack = UploadPack(str(root_path), path, identity)
     assert pack.is_data_file is True
     assert pack.is_hidden_file is False
     assert pack.clear_file_exists is False
@@ -360,7 +391,7 @@ def test_packer_data_clear_no_clear():
 @use_test_database
 def test_packer_data_zip_no_clear():
     path = str(fixture_path / 'data_zipped_no_clear.fits.zip')
-    pack = UploadPack(root_path, path, identity)
+    pack = UploadPack(str(root_path), path, identity)
     assert pack.is_data_file is True
     assert pack.is_hidden_file is False
     assert pack.clear_file_exists is False
@@ -371,7 +402,7 @@ def test_packer_data_zip_no_clear():
 @use_test_database
 def test_packer_data_gzip_no_clear():
     path = str(fixture_path / 'data_zipped_no_clear.fits.gz')
-    pack = UploadPack(root_path, path, identity)
+    pack = UploadPack(str(root_path), path, identity)
     assert pack.is_data_file is True
     assert pack.is_hidden_file is False
     assert pack.clear_file_exists is False
@@ -382,9 +413,23 @@ def test_packer_data_gzip_no_clear():
 @use_test_database
 def test_packer_data_bz2_no_clear():
     path = str(fixture_path / 'data_zipped_no_clear.fits.bz2')
-    pack = UploadPack(root_path, path, identity)
+    pack = UploadPack(str(root_path), path, identity)
     assert pack.is_data_file is True
     assert pack.is_hidden_file is False
     assert pack.clear_file_exists is False
     assert pack.zipped_file_exists is True
     assert pack.should_zip is False
+
+
+@use_test_database
+def test_packer_data_pure_zip():
+    path = str(fixture_path / 'dummy.zip')
+    pack = UploadPack(str(root_path), path, identity)
+    assert pack.clear_file_path.endswith('dummy.zip')
+
+
+@use_test_database
+def test_packer_data_txt_zip():
+    path = str(fixture_path / 'dummy.txt.zip')
+    pack = UploadPack(str(root_path), path, identity)
+    assert pack.clear_file_path.endswith('dummy.txt')
