@@ -9,8 +9,8 @@ from oort.shared.identity import Identity
 from oort.shared.models import Calibration, Dataset, NightLog, Observation, Organisation, Telescope, Upload, db
 from oort.uploader.engine.packer import UploadPack
 from oort.uploader.engine.uploader import FileUploader
-from tests.utils import (TEST_CUSTOM_UPLOAD_KEY, TEST_CUSTOM_USERNAME, TEST_LOGIN_UPLOAD_KEY, TEST_LOGIN_ORG_ROLE,
-                         TEST_LOGIN_ORG_SUBDOMAIN, TEST_LOGIN_USERNAME, use_test_database)
+from tests.utils import (TEST_CUSTOM_UPLOAD_KEY, TEST_CUSTOM_USERNAME, TEST_LOGIN_ORG_ROLE, TEST_LOGIN_ORG_SUBDOMAIN,
+                         TEST_LOGIN_UPLOAD_KEY, TEST_LOGIN_USERNAME, use_test_database)
 
 spec = importlib.util.find_spec('oort')
 
@@ -29,7 +29,7 @@ def test_uploader_init_no_org():
     identity = Identity(TEST_LOGIN_USERNAME, TEST_LOGIN_UPLOAD_KEY, debug=True)
     pack = UploadPack(folder_path, fits_file_path, identity)
     dataset = Dataset.smart_create(uuid=str(uuid.uuid4()))
-    pack.upload.smart_update(dataset=dataset)
+    pack.update_upload(dataset=dataset)
 
     with patch.object(ArcsecondAPI, 'datafiles') as mock_api:
         uploader = FileUploader(pack)
@@ -53,7 +53,7 @@ def test_uploader_init_org():
 
     pack = UploadPack(folder_path, fits_file_path, identity)
     dataset = Dataset.smart_create(uuid=str(uuid.uuid4()))
-    pack.upload.smart_update(dataset=dataset)
+    pack.update_upload(dataset=dataset)
 
     with patch.object(ArcsecondAPI, 'datafiles') as mock_api:
         uploader = FileUploader(pack)
@@ -77,7 +77,7 @@ def test_uploader_init_org_custom_astronomer():
 
     pack = UploadPack(folder_path, fits_file_path, identity)
     dataset = Dataset.smart_create(uuid=str(uuid.uuid4()))
-    pack.upload.smart_update(dataset=dataset)
+    pack.update_upload(dataset=dataset)
 
     with patch.object(ArcsecondAPI, 'datafiles') as mock_api:
         uploader = FileUploader(pack)
